from .dumpulator import Dumpulator
from .ntsyscalls import syscall
